pub struct Module {
pub root: Region,
}Expand description
A module in the hugr AST.
See table::Module for the table representation.
Fields
root: RegionThe root region of the module.
This must be a region of kind RegionKind::Module.
Implementations
Sourceimpl Module
impl Module
Sourcepub fn resolve<'a>(&'a self, bump: &'a Bump) -> Result<Module<'a>, ResolveError>
pub fn resolve<'a>(&'a self, bump: &'a Bump) -> Result<Module<'a>, ResolveError>
Try to convert this module into the table representation.
This conversion resolves the names of variables, symbols and links
according to their scoping rules described in the scope module.
Symbols may be versioned either at their import/declaration/definition site or at their use site. Unversioned references will be resolved to the latest declared version if one is available.
Whenever a symbol is used but not defined in scope, an import node will be inserted into the module region and all references to that symbol will refer to the import node. This gives the opportunity to link the missing symbols.